@@ -55,7 +55,8 @@ Full tutorial on yattag.org_
 """
 
 __author__ = "Benjamin Le Forestier (benjamin@leforestier.org)"
-__version__ = '0.8.1'
+__version__ = '0.9.6'
 
-from .simpledoc import SimpleDoc
-from .doc import Doc
+from yattag.simpledoc import SimpleDoc
+from yattag.doc import Doc
+from yattag.indentation import indent
